@@ -11,12 +11,10 @@ our @ISA = qw(Exporter DynaLoader);
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 our @EXPORT = qw(
-);
-our @EXPORT_OK = qw(
 totalmem
 freemem
 );
-our $VERSION = 0.05;
+our $VERSION = 0.01;
 bootstrap Sys::MemInfo $VERSION;
 
 =pod
@@ -34,9 +32,9 @@ Sys::MemInfo - Memory informations
 
 Sys::MemInfo return the total amount of free and used physical memory in bytes in totalmem and freemem variables.
 
-This module has been tested on Linux, OpenUnix, AIX5, OpenBSD, HPUX11, Tru64 5.1 and Windows XP.
+This module has been tested on Linux, OpenUnix, AIX5 and OpenBSD.
 
-It should work on Solaris, Windows Server 2003 and others *bsd systems like FreeBSD and NetBSD.
+It should work on Solaris and others *bsd systems like FreeBSD and NetBSD.
 
 =head1 AUTHOR
 
@@ -65,7 +63,7 @@ USA
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005, 2006 - Sylvain Cresto
+Copyright (C) 2005 - Sylvain Cresto
 
 =cut
 
